@@ -24,12 +24,14 @@
 
 #include <QAbstractItemView>
 #include <QList>
+#include <QString>
 #include <QStyleOption>
 
 class DolphinColumnWidget;
 class DolphinController;
 class DolphinModel;
 class QAbstractProxyModel;
+class QFrame;
 class QTimeLine;
 
 /**
@@ -69,6 +71,18 @@ public:
     /** Returns the URL of the first column. */
     KUrl rootUrl() const;
 
+    /**
+     * Filters the currently shown items by \a nameFilter. All items
+     * which contain the given filter string will be shown.
+     */
+    void setNameFilter(const QString& nameFilter);
+
+    /**
+     * Returns the currently used name filter. All items
+     * which contain the name filter will be shown.
+     */
+    QString nameFilter() const;
+
 public slots:
     /**
      * Shows the column which represents the URL \a url. If the column
@@ -156,6 +170,7 @@ private:
     int m_index;
     int m_contentX;
     QList<DolphinColumnWidget*> m_columns;
+    QFrame* m_emptyViewport;
     QTimeLine* m_animation;
 
     friend class DolphinColumnWidget;
