@@ -698,19 +698,11 @@ void DolphinMainWindow::invertSelection()
     clearStatusBar();
     m_activeViewContainer->view()->invertSelection();
 }
-void DolphinMainWindow::setIconsView()
-{
-    m_activeViewContainer->view()->setMode(DolphinView::IconsView);
-}
 
-void DolphinMainWindow::setDetailsView()
+void DolphinMainWindow::setViewMode(QAction* action)
 {
-    m_activeViewContainer->view()->setMode(DolphinView::DetailsView);
-}
-
-void DolphinMainWindow::setColumnView()
-{
-    m_activeViewContainer->view()->setMode(DolphinView::ColumnView);
+    const DolphinView::Mode mode = action->data().value<DolphinView::Mode>();
+    m_activeViewContainer->view()->setMode(mode);
 }
 
 void DolphinMainWindow::sortByName()
@@ -1104,7 +1096,7 @@ void DolphinMainWindow::setupActions()
 
     QAction* moveToTrash = actionCollection()->addAction("move_to_trash");
     moveToTrash->setText(i18nc("@action:inmenu File", "Move to Trash"));
-    moveToTrash->setIcon(KIcon("edit-trash"));
+    moveToTrash->setIcon(KIcon("user-trash"));
     moveToTrash->setShortcut(QKeySequence::Delete);
     connect(moveToTrash, SIGNAL(triggered()), this, SLOT(moveToTrash()));
 
@@ -1149,28 +1141,16 @@ void DolphinMainWindow::setupActions()
                              SLOT(zoomOut()),
                              actionCollection());
 
-    KToggleAction* iconsView = actionCollection()->add<KToggleAction>("icons");
-    iconsView->setText(i18nc("@action:inmenu View Mode", "Icons"));
-    iconsView->setShortcut(Qt::CTRL | Qt::Key_1);
-    iconsView->setIcon(KIcon("fileview-icon"));
-    connect(iconsView, SIGNAL(triggered()), this, SLOT(setIconsView()));
 
-    KToggleAction* detailsView = actionCollection()->add<KToggleAction>("details");
-    detailsView->setText(i18nc("@action:inmenu View Mode", "Details"));
-    detailsView->setShortcut(Qt::CTRL | Qt::Key_2);
-    detailsView->setIcon(KIcon("fileview-detailed"));
-    connect(detailsView, SIGNAL(triggered()), this, SLOT(setDetailsView()));
-
-    KToggleAction* columnView = actionCollection()->add<KToggleAction>("columns");
-    columnView->setText(i18nc("@action:inmenu View Mode", "Columns"));
-    columnView->setShortcut(Qt::CTRL | Qt::Key_3);
-    columnView->setIcon(KIcon("fileview-column"));
-    connect(columnView, SIGNAL(triggered()), this, SLOT(setColumnView()));
+    KToggleAction* iconsView = DolphinView::iconsModeAction(actionCollection());
+    KToggleAction* detailsView = DolphinView::detailsModeAction(actionCollection());
+    KToggleAction* columnView = DolphinView::columnsModeAction(actionCollection());
 
     QActionGroup* viewModeGroup = new QActionGroup(this);
     viewModeGroup->addAction(iconsView);
     viewModeGroup->addAction(detailsView);
     viewModeGroup->addAction(columnView);
+    connect(viewModeGroup, SIGNAL(triggered(QAction*)), this, SLOT(setViewMode(QAction*)));
 
     KToggleAction* sortByName = actionCollection()->add<KToggleAction>("sort_by_name");
     sortByName->setText(i18nc("@action:inmenu Sort By", "Name"));
@@ -1390,22 +1370,23 @@ void DolphinMainWindow::setupDockWidgets()
         terminalDock->hide();
     }
 
-    QDockWidget *placesDock = new QDockWidget(i18nc("@title:window", "Places"));
+    QDockWidget* placesDock = new QDockWidget(i18nc("@title:window", "Places"));
     placesDock->setObjectName("placesDock");
     placesDock->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
-    KFilePlacesView *listView = new KFilePlacesView(placesDock);
-    placesDock->setWidget(listView);
-    listView->setModel(DolphinSettings::instance().placesModel());
+    KFilePlacesView* placesView = new KFilePlacesView(placesDock);
+    placesDock->setWidget(placesView);
+    placesView->setModel(DolphinSettings::instance().placesModel());
+    placesView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
     placesDock->toggleViewAction()->setText(i18nc("@title:window", "Places"));
     placesDock->toggleViewAction()->setShortcut(Qt::Key_F9);
     actionCollection()->addAction("show_places_panel", placesDock->toggleViewAction());
 
     addDockWidget(Qt::LeftDockWidgetArea, placesDock);
-    connect(listView, SIGNAL(urlChanged(KUrl)),
+    connect(placesView, SIGNAL(urlChanged(KUrl)),
             this, SLOT(changeUrl(KUrl)));
     connect(this, SIGNAL(urlChanged(KUrl)),
-            listView, SLOT(setUrl(KUrl)));
+            placesView, SLOT(setUrl(KUrl)));
 }
 
 void DolphinMainWindow::updateHistory()
@@ -1469,21 +1450,7 @@ void DolphinMainWindow::updateViewActions()
         zoomOutAction->setEnabled(view->isZoomOutPossible());
     }
 
-    QAction* action = 0;
-    switch (view->mode()) {
-    case DolphinView::IconsView:
-        action = actionCollection()->action("icons");
-        break;
-    case DolphinView::DetailsView:
-        action = actionCollection()->action("details");
-        break;
-    case DolphinView::ColumnView:
-        action = actionCollection()->action("columns");
-        break;
-    default:
-        break;
-    }
-
+    QAction* action = actionCollection()->action(view->currentViewModeActionName());
     if (action != 0) {
         KToggleAction* toggleAction = static_cast<KToggleAction*>(action);
         toggleAction->setChecked(true);
