@@ -67,6 +67,20 @@ private Q_SLOTS:
      * @url   URL which contains \a item.
      */
     void slotOpenContextMenu(const KFileItem& item, const KUrl& url);
+    /**
+     * Emitted when the user requested a change of view mode
+     */
+    void slotViewModeActionTriggered(QAction*);
+
+    /**
+     * Asks the host to open the URL \a url if the current view has
+     * a different URL.
+     */
+    void slotUrlChanged(const KUrl& url);
+
+private:
+    void createActions();
+    void updateViewActions();
 
 private:
     DolphinView* m_view;
