@@ -37,6 +37,7 @@
 #include <QListView>
 #include <QWidget>
 
+class KToggleAction;
 class DolphinController;
 class KDirLister;
 class KFileItemDelegate;
@@ -304,6 +305,44 @@ public:
      */
     void updateView(const KUrl& url, const KUrl& rootUrl);
 
+    /**
+     * Filters the currently shown items by \a nameFilter. All items
+     * which contain the given filter string will be shown.
+     */
+    void setNameFilter(const QString& nameFilter);
+
+    /**
+     * Calculates the number of currently shown files into
+     * \a fileCount and the number of folders into \a folderCount.
+     * It is recommend using this method instead of asking the
+     * directory lister or the model directly, as it takes
+     * filtering and hierarchical previews into account.
+     */
+    void calculateItemCount(int& fileCount, int& folderCount);
+
+    /**
+     * Returns the "switch to icons mode" action.
+     * This code is here to share it between the mainwindow and the part
+     */
+    static KToggleAction* iconsModeAction(KActionCollection* collection);
+
+    /**
+     * Returns the "switch to details mode" action.
+     * This code is here to share it between the mainwindow and the part
+     */
+    static KToggleAction* detailsModeAction(KActionCollection* collection);
+
+    /**
+     * Returns the "switch to columns mode" action.
+     * This code is here to share it between the mainwindow and the part
+     */
+    static KToggleAction* columnsModeAction(KActionCollection* collection);
+
+    /**
+     * Returns the action name corresponding to the current view mode
+     */
+    QString currentViewModeActionName() const;
+
 public slots:
     /**
      * Changes the directory to \a url. If the current directory is equal to
@@ -319,6 +358,7 @@ public slots:
      */
     void changeSelection(const KFileItemList& selection);
 
+
 signals:
     /**
      * Is emitted if the view has been activated by e. g. a mouse click.
@@ -587,4 +627,7 @@ private:
     KUrl m_rootUrl;
 };
 
+/// Allow using DolphinView::Mode in QVariant
+Q_DECLARE_METATYPE(DolphinView::Mode)
+
 #endif // DOLPHINVIEW_H
