@@ -112,6 +112,8 @@ public:
       */
     void drawDraggedItems();
 
+    void layoutChanged(bool forceItemReload = false);
+
 
     // Attributes
 
@@ -149,6 +151,11 @@ public:
     QModelIndexList intersectedIndexes;
     QRect lastDraggedItemsRect;
     QRect lastSelectionRect;
+    int modelSortRole;
+    int modelSortColumn;
+    int modelLastRowCount;
+    bool modelCategorized;
+    Qt::SortOrder modelSortOrder;
 
     // Attributes for speed reasons
     KCategorizedSortFilterProxyModel *proxyModel;
