@@ -21,7 +21,6 @@
 #include "statusbarmessagelabel.h"
 
 #include <kcolorscheme.h>
-#include <kcolorutils.h>
 #include <kiconloader.h>
 #include <kicon.h>
 #include <klocale.h>
@@ -59,7 +58,8 @@ StatusBarMessageLabel::StatusBarMessageLabel(QWidget* parent) :
 }
 
 StatusBarMessageLabel::~StatusBarMessageLabel()
-{}
+{
+}
 
 void StatusBarMessageLabel::setMessage(const QString& text,
                                        DolphinStatusBar::Type type)
@@ -122,7 +122,9 @@ void StatusBarMessageLabel::setMinimumTextHeight(int min)
     if (min != m_minTextHeight) {
         m_minTextHeight = min;
         setMinimumHeight(min);
-        m_closeButton->setFixedHeight(min - borderGap() * 2);
+        if (m_closeButton->height() > min) {
+            m_closeButton->setFixedHeight(min);
+        }
     }
 }
 
@@ -138,30 +140,30 @@ void StatusBarMessageLabel::paintEvent(QPaintEvent* /* event */)
     QPainter painter(this);
 
     // draw background
-    QColor backgroundColor = palette().brush(QPalette::Background).color();
-    QColor foregroundColor = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
+    QColor backgroundColor = palette().window().color();
     if (m_illumination > 0) {
-        // TODO: are there foreground and background colors available for
-        // "error messages"?
-        backgroundColor.setRgb(255, 255, 0, m_illumination);
-        QColor mixColor(0, 0, 0, m_illumination);
-        foregroundColor = KColorUtils::overlayColors(foregroundColor, mixColor);
+        // at this point, a: we are a second label being drawn over the already
+        // painted status area, so we can be translucent, and b: our palette's
+        // window color (bg only) seems to be wrong (always black)
+        KColorScheme scheme(palette().currentColorGroup(), KColorScheme::Window);
+        backgroundColor = scheme.background(KColorScheme::NegativeBackground).color();
+        backgroundColor.setAlpha(qMin(255, m_illumination*2));
     }
     painter.setBrush(backgroundColor);
-    painter.setPen(backgroundColor);
+    painter.setPen(Qt::NoPen);
     painter.drawRect(QRect(0, 0, width(), height()));
 
     // draw pixmap
-    int x = borderGap();
+    int x = BorderGap;
     int y = (m_minTextHeight - m_pixmap.height()) / 2;
 
     if (!m_pixmap.isNull()) {
         painter.drawPixmap(x, y, m_pixmap);
-        x += m_pixmap.width() + borderGap();
+        x += m_pixmap.width() + BorderGap;
     }
 
     // draw text
-    painter.setPen(foregroundColor);
+    painter.setPen(palette().windowText().color());
     int flags = Qt::AlignVCenter;
     if (height() > m_minTextHeight) {
         flags = flags | Qt::TextWordWrap;
@@ -265,14 +267,14 @@ void StatusBarMessageLabel::assureVisibleText()
 int StatusBarMessageLabel::availableTextWidth() const
 {
     const int buttonWidth = (m_type == DolphinStatusBar::Error) ?
-                            m_closeButton->width() + borderGap() : 0;
-    return width() - m_pixmap.width() - (borderGap() * 4) - buttonWidth;
+                            m_closeButton->width() + BorderGap : 0;
+    return width() - m_pixmap.width() - (BorderGap * 4) - buttonWidth;
 }
 
 void StatusBarMessageLabel::updateCloseButtonPosition()
 {
-    const int x = width() - m_closeButton->width() - borderGap();
-    const int y = height() - m_closeButton->height() - borderGap();
+    const int x = width() - m_closeButton->width() - BorderGap;
+    const int y = (height() - m_closeButton->height()) / 2;
     m_closeButton->move(x, y);
 }
 
