@@ -75,12 +75,11 @@ void TreeViewContextMenu::open()
     popup->addAction(renameAction);
 
     // insert 'Move to Trash' and (optionally) 'Delete'
-    const KSharedConfig::Ptr globalConfig = KSharedConfig::openConfig("kdeglobals", KConfig::NoGlobals);
-    const KConfigGroup kdeConfig(globalConfig, "KDE");
+    KConfigGroup kdeConfig(KGlobal::config(), "KDE");
     bool showDeleteCommand = kdeConfig.readEntry("ShowDeleteCommand", false);
     const KUrl& url = m_fileInfo.url();
     if (url.isLocalFile()) {
-        QAction* moveToTrashAction = new QAction(KIcon("edit-trash"),
+        QAction* moveToTrashAction = new QAction(KIcon("user-trash"),
                                                  i18nc("@action:inmenu", "Move To Trash"), this);
         connect(moveToTrashAction, SIGNAL(triggered()), this, SLOT(moveToTrash()));
         popup->addAction(moveToTrashAction);
