@@ -324,7 +324,7 @@ void KonqCombo::loadItems()
     historyConfigGroup.writeEntry( "CompletionItems", "unused" );
 
     KConfigGroup locationBarGroup( s_config, "Location Bar" );
-    const QStringList items = locationBarGroup.readPathListEntry( "ComboContents" );
+    const QStringList items = locationBarGroup.readPathEntry( "ComboContents", QStringList() );
     QStringList::ConstIterator it = items.begin();
     QString item;
     bool first = true;
@@ -645,7 +645,7 @@ void KonqCombo::paintEvent( QPaintEvent *pe )
 	if ( useColor)
 	    edit->setPaletteBackgroundColor( color );
 
-        pix = SmallIcon( m_pageSecurity==KonqMainWindow::Encrypted ? "encrypted" : "halfencrypted" );
+        pix = SmallIcon( m_pageSecurity==KonqMainWindow::Encrypted ? "security-high" : "security-medium" );
         p.fillRect( re.right() - pix.width() - 3 , re.y(), pix.width() + 4, re.height(),
 		    QBrush( useColor ? color : edit->paletteBackgroundColor() ));
         p.drawPixmap( re.right() - pix.width() -1 , re.y() + ( re.height() - pix.height() ) / 2, pix );
