@@ -142,8 +142,9 @@ public:
   // Central widget of the mainwindow, never 0L
   QWidget *mainWidget() const;
 
-  virtual QWidget *createContainer( QWidget *parent, int index, const QDomElement &element, int &id );
-  virtual void removeContainer( QWidget *container, QWidget *parent, QDomElement &element, int id );
+  // KXMLGUIBuilder methods
+  virtual QWidget *createContainer( QWidget *parent, int index, const QDomElement &element, QAction* &containerAction );
+  virtual void removeContainer( QWidget *container, QWidget *parent, QDomElement &element, QAction* containerAction );
 
   virtual void saveProperties( KConfig& config );
   virtual void readProperties( KConfig& config );
@@ -646,7 +647,7 @@ private: // members
   QAction *m_paMoveTabRight;
 
   QAction *m_paConfigureExtensions;
-  QAction *m_paConfigureSpellChecking;
+  //QAction *m_paConfigureSpellChecking;
 
   KAnimatedButton *m_paAnimatedLogo;
 
