@@ -487,8 +487,8 @@ void UrlFilter::HotSpot::activate(QObject* object)
 
 //regexp matches:
 // full url:  
-// protocolname:// or www. followed by numbers, letters dots and dashes or the '@' character. 
-const QRegExp UrlFilter::FullUrlRegExp("([a-z]+://|www\\.)[^\\s]+");
+// protocolname:// or www. followed by anything other than whitespaces, >, ' or ", and ends before whitespaces, >, ), ', ", ] and . (dot)
+const QRegExp UrlFilter::FullUrlRegExp("(www\\.(?!\\.)|[a-z][a-z0-9+.-]*://)[^\\s>'\"]+[^\\.\\s>\\)'\"\\]]");
 // email address:
 // [word chars, dots or dashes]@[word chars, dots or dashes].[word chars]
 const QRegExp UrlFilter::EmailAddressRegExp("(\\w|\\.|-)+@(\\w|\\.|-)+\\.\\w+");
