@@ -33,6 +33,7 @@
 #include <KGlobal>
 #include <KGlobalSettings>
 #include <KLocale>
+#include <KDebug>
 #include <KStandardDirs>
 
 // Konsole
@@ -74,7 +75,6 @@ const Profile::PropertyNamePair Profile::DefaultPropertyNames[] =
     , { HistoryMode , "HistoryMode" }
     , { HistorySize , "HistorySize" } 
     , { ScrollBarPosition , "ScrollBarPosition" }
-    , { SelectWordCharacters , "SelectWordCharacters" }
     , { BlinkingTextEnabled , "BlinkingTextEnabled" }
     , { FlowControlEnabled , "FlowControlEnabled" }
     , { AllowProgramsToResizeWindow , "AllowProgramsToResizeWindow" }
@@ -114,7 +114,7 @@ FallbackProfile::FallbackProfile()
     // Fallback settings
     setProperty(Name,i18n("Shell"));
     setProperty(Command,getenv("SHELL"));
-    setProperty(Icon,"konsole");
+    setProperty(Icon,"utilities-terminal");
     setProperty(Arguments,QStringList() << getenv("SHELL"));
     setProperty(Environment,QStringList() << "TERM=xterm");
     setProperty(LocalTabTitleFormat,"%d : %n");
