@@ -377,9 +377,9 @@ void KonqPopupMenuPrivate::setup(KonqPopupMenu::Flags kpf)
     if (m_itemFlags & KParts::BrowserExtension::ShowNavigationItems)
     {
         if (m_itemFlags & KParts::BrowserExtension::ShowUp)
-            addNamedAction( "up" );
-        addNamedAction( "back" );
-        addNamedAction( "forward" );
+            addNamedAction( "go_up" );
+        addNamedAction( "go_back" );
+        addNamedAction( "go_forward" );
         if (m_itemFlags & KParts::BrowserExtension::ShowReload)
             addNamedAction( "reload" );
         q->addSeparator();
@@ -440,9 +440,9 @@ void KonqPopupMenuPrivate::setup(KonqPopupMenu::Flags kpf)
     if ( isCurrentTrash )
     {
         act = m_ownActions.addAction( "emptytrash" );
-        act->setIcon( KIcon("emptytrash") );
+        act->setIcon( KIcon("trash-empty") );
         act->setText( i18n( "&Empty Trash Bin" ) );
-        KConfig trashConfig( "trashrc", KConfig::OnlyLocal);
+        KConfig trashConfig( "trashrc", KConfig::SimpleConfig);
         act->setEnabled( !trashConfig.group("Status").readEntry( "Empty", true ) );
         QObject::connect(act, SIGNAL(triggered()), q, SLOT(slotPopupEmptyTrashBin()));
         q->addAction(act);
